﻿using System;
using System.Text;

namespace Nyerguds.Util.UI
{
    /// <summary>
    /// Class to use a list of encodings as datasource for a UI element. UI elements like that use the objects' ToString representations.
    /// The  main reasons for using this class are the fact it can differentiate between UTF-8 encoding with and without byte order mark,
    /// and the fact it supports customizing the string representation, specifically for a null default in the list.
    /// </summary>
    public class ListItemEncoding : DataSourceListItem<ListItemEncoding,Encoding>
    {
                
        protected override String GetObjectString()
        {
            if (this.InternalObject is UTF8Encoding)
            {
                UTF8Encoding enc = (UTF8Encoding)this.InternalObject;
                Byte[] preamble = enc.GetPreamble();
                // UTF-8 or UTF-8 with no byte order mark. Big difference.
                if (preamble == null || preamble.Length == 0)
                    return InternalObject.WebName + " (NBOM)";
            }
            return InternalObject.WebName;
        }

    }
}
